# Sequestering activity

A sequestering activity is defined as the binding to a specific molecule to prevent it from interacting with other partners or to inhibit its localization to the area of the cell or complex where the target is active.

# Pathway Editor

The activity unit for sequestering activity is:

* **MF**: molecular sequestering activity ([GO:0140313](https://www.ebi.ac.uk/QuickGO/term/GO%3A0140313)) or a child
* **Context:**
  + The relation between the protein that act to sequester and its target receptor is *'*has input'
  + **BP**: the BP it inhibits
  + **CC**: the place where the activity occurs.
  + The causal relation between the **sequestering activity** and the activity of the protein it inhibits is 'directly positively regulates'.

Example 1: [Sequestering activity of CAV1 on TLR4 signaling](http://noctua.geneontology.org/workbench/noctua-visual-pathway-editor/?model_id=gomodel%3A645d887900001414)

![A screenshot of a computer

Description automatically generated with medium confidence](data:image/png;base64...)

The molecular activity unit for molecular adaptor may include:

o **MF**: molecular sequestering activity ([GO:0140313](https://www.ebi.ac.uk/QuickGO/term/GO%3A0140313)) or one of its children

o

The relation with the downstream activity used is **“directly negatively regulates”**

Example 2: [Sequestering activity of YWHAZ on RAF1](http://noctua.geneontology.org/workbench/noctua-visual-pathway-editor/?model_id=gomodel%3A63d320cd00000820)

![](data:image/png;base64...)

In that example, the difference in the cellular component between the two activities clearly show that the YWHAZ protein sequesters RAF1 in the cytoplasm, preventing its activity in the plasma membrane.

The relation used between both activities is **“directly negatively regulates”** because there is direct interaction between both proteins.

# Form Editor

Review date: 2023-06-22

Reviewed by: Pascale Gaudet, Patrick Masson
